From khali@linux-fr.org Sun Sep  4 13:57:04 2005
Date: Sun, 4 Sep 2005 22:52:17 +0200
From: Jean Delvare <khali@linux-fr.org>
To: Greg KH <greg@kroah.com>
Cc: Roberto Colmegna <rcolmegna@tiscali.it>
Subject: hwmon: w83627hf: no reset by default
Message-Id: <20050904225217.13625bd2.khali@linux-fr.org>

Make the reset of the chips in w83627hf optional rather than the
default. This reset has been causing trouble several times already. It
may even go completely away unless it proves to be useful to at least
one user.

Closes bug #5168:
http://bugzilla.kernel.org/show_bug.cgi?id=5168

Signed-off-by: Jean Delvare <khali@linux-fr.org>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>


---
 drivers/hwmon/w83627hf.c |   14 +++++++++++++-
 1 file changed, 13 insertions(+), 1 deletion(-)

--- gregkh-2.6.orig/drivers/hwmon/w83627hf.c	2005-09-09 10:28:55.000000000 -0700
+++ gregkh-2.6/drivers/hwmon/w83627hf.c	2005-09-09 14:30:17.000000000 -0700
@@ -64,6 +64,10 @@ static unsigned short address;
 /* Insmod parameters */
 enum chips { any_chip, w83627hf, w83627thf, w83697hf, w83637hf };
 
+static int reset;
+module_param(reset, bool, 0);
+MODULE_PARM_DESC(reset, "Set to one to reset chip on load");
+
 static int init = 1;
 module_param(init, bool, 0);
 MODULE_PARM_DESC(init, "Set to zero to bypass chip initialization");
@@ -1279,7 +1283,15 @@ static void w83627hf_init_client(struct 
 	int type = data->type;
 	u8 tmp;
 
-	if(init) {
+	if (reset) {
+		/* Resetting the chip has been the default for a long time,
+		   but repeatedly caused problems (fans going to full
+		   speed...) so it is now optional. It might even go away if
+		   nobody reports it as being useful, as I see very little
+		   reason why this would be needed at all. */
+		dev_info(&client->dev, "If reset=1 solved a problem you were "
+			 "having, please report!\n");
+
 		/* save this register */
 		i = w83627hf_read_value(client, W83781D_REG_BEEP_CONFIG);
 		/* Reset all except Watchdog values and last conversion values
